@@ -64,9 +64,16 @@ class Service(enum.Enum):
     PyThaiNLP = enum.auto()
     Spacy = enum.auto()
     ArgosTranslate = enum.auto()
+    Wenlin = enum.auto()
 
 class Gender(enum.Enum):
     Male = enum.auto()
     Female = enum.auto()
     Any = enum.auto()
 
+
+class DictionaryLookupType(enum.Enum):
+    Definitions = enum.auto()
+    PartOfSpeech = enum.auto()
+    MeasureWord = enum.auto()
+    PartOfSpeechDefinitions = enum.auto()
\ No newline at end of file
