@@ -15,11 +15,15 @@ class Language(enum.Enum):
     ba = ("Bashkir")
     bo = ("Tibetan")
     be = ("Belarusian")
+    bm = ("Bambara")
+    bho = ("Bhojpuri")
     bn = ("Bangla")
     bs = ("Bosnian")
     bg = ("Bulgarian")
     ca = ("Catalan")
     ceb = ("Cebuano")
+    ckb = ("Kurdish (Sorani)")
+    doi = ("Dogri")
     ny = ("Chichewa")
     co = ("Corsican")
     hr = ("Croatian")
@@ -40,6 +44,7 @@ class Language(enum.Enum):
     ka = ("Georgian")
     de = ("German")
     el = ("Greek")
+    gom = ("Goan Konkani")
     gn = ("Guarani")
     gu = ("Gujarati")
     ht = ("Haitian Creole")
@@ -56,6 +61,7 @@ class Language(enum.Enum):
     is_ = ("Icelandic")
     ig = ("Igbo")
     id_ = ("Indonesian")
+    ilo = ("Iloko")
     ga = ("Irish")
     it = ("Italian")
     ja = ("Japanese")
@@ -66,6 +72,7 @@ class Language(enum.Enum):
     kri = ("Krio")
     lg = ("Luganda")
     ln = ("Lingala")
+    lus = ("Mizo")
     rw = ("Kinyarwanda")
     ko = ("Korean")
     ku = ("Kurdish (Central)")
@@ -75,6 +82,7 @@ class Language(enum.Enum):
     lv = ("Latvian")
     lt = ("Lithuanian")
     lb = ("Luxembourgish")
+    mai = ("Maithili")
     mk = ("Macedonian")
     mg = ("Malagasy")
     ms = ("Malay")
@@ -83,6 +91,7 @@ class Language(enum.Enum):
     mi = ("Maori")
     mr = ("Marathi")
     mn = ("Mongolian")
+    mni = ("Manipuri (Meitei Mayek)")
     mn_cyrl = ("Mongolian (Cyrillic)")
     cnr = ("Montenegrin")
     my = ("Myanmar (Burmese)")
